@@ -1095,7 +1095,8 @@ def prune_conformers_rmsd_rot_corr(structures, atomnos, graph, max_rmsd=0.25, ve
                 else:
                     _l = len(range(d*step, int(d*(step+1))))
 
-                similarity_mat = np.zeros((_l, _l))
+                # similarity_mat = np.zeros((_l, _l))
+                matches = set()
 
                 for i_rel in range(_l):
                     for j_rel in range(i_rel+1,_l):
@@ -1115,19 +1116,23 @@ def prune_conformers_rmsd_rot_corr(structures, atomnos, graph, max_rmsd=0.25, ve
                                                                angles)
 
                             if rmsd < max_rmsd:
-                                similarity_mat[i_rel,j_rel] = 1
+                                # similarity_mat[i_rel,j_rel] = 1
+                                matches.add((i_rel,j_rel))
                                 break
-
-                for i_rel, j_rel in zip(*np.where(similarity_mat == False)):
-                    i_abs = i_rel+(d*step)
-                    j_abs = j_rel+(d*step)
-                    cache_set.add((i_abs, j_abs))
+                            else:
+                                i_abs = i_rel+(d*step)
+                                j_abs = j_rel+(d*step)
+                                cache_set.add((i_abs, j_abs))
+                # for i_rel, j_rel in zip(*np.where(similarity_mat == False)):
+                #     i_abs = i_rel+(d*step)
+                #     j_abs = j_rel+(d*step)
+                #     cache_set.add((i_abs, j_abs))
                     # adding indices of structures that are considered equal,
                     # so as not to repeat computing their RMSD
                     # Their index accounts for their position in the initial
                     # array (absolute index)
 
-                matches = [(i,j) for i,j in zip(*np.where(similarity_mat))]
+                # matches = [(i,j) for i,j in zip(*np.where(similarity_mat))]
                 g = nx.Graph(matches)
 
                 subgraphs = [g.subgraph(c) for c in nx.connected_components(g)]
